==> terminhtml-0.4.1-py3-none-any.whl: terminhtml/demo_output.py <==
# Adapted from rich.__main__.py
import colorsys
import time

from rich.color import Color
from rich.console import ConsoleOptions, Console, RenderResult
from rich.measure import Measurement
from rich.progress_bar import ProgressBar
from rich.prompt import Prompt
from rich.segment import Segment
from rich.style import Style
from rich.table import Table


class ColorBox:
    def __rich_console__(
        self, console: Console, options: ConsoleOptions
    ) -> RenderResult:
        for y in range(0, 5):
            for x in range(options.max_width):
                h = x / options.max_width
                l = 0.1 + ((y / 5) * 0.7)
                r1, g1, b1 = colorsys.hls_to_rgb(h, l, 1.0)
                r2, g2, b2 = colorsys.hls_to_rgb(h, l + 0.7 / 10, 1.0)
                bgcolor = Color.from_rgb(r1 * 255, g1 * 255, b1 * 255)
                color = Color.from_rgb(r2 * 255, g2 * 255, b2 * 255)
                yield Segment("▄", Style(color=color, bgcolor=bgcolor))
            yield Segment.line()

    def __rich_measure__(
        self, console: "Console", options: ConsoleOptions
    ) -> Measurement:
        return Measurement(1, options.max_width)


def make_test_card() -> Table:
    """Get a renderable that demonstrates a number of features."""
    table = Table.grid(padding=1, pad_edge=True)
    table.title = "Terminal recording into HTML/CSS with full color and animation support"
    table.add_column("Feature", no_wrap=True, justify="center", style="bold red")
    table.add_column("Demonstration")

    color_table = Table(
        box=None,
        expand=False,
        show_header=False,
        show_edge=False,
        pad_edge=False,
    )
    color_table.add_row(
        (
            "✓ [bold green]4-bit color[/]\n"
            "✓ [bold blue]8-bit color[/]\n"
            "✓ [bold magenta]Truecolor (16.7 million)[/]\n"
            "✓ [bold yellow]Dumb terminals[/]\n"
            "✓ [bold cyan]Automatic color conversion"
        ),
        ColorBox(),
    )

    table.add_row("Colors", color_table)

    table.add_row(
        "Styles",
        "All ansi styles: [bold]bold[/], [dim]dim[/], [italic]italic[/italic], [underline]underline[/], [strike]strikethrough[/], [reverse]reverse[/], and even [blink]blink[/].",
    )

    return table

if __name__ == "__main__":  # pragma: no cover
    console = Console()
    test_card = make_test_card()
    console.print(test_card)

    console.print("[bold red]Progress bars[/bold red] work too")

    bar = ProgressBar(width=50, total=100)

    import time

    console.show_cursor(False)
    for n in range(0, 101, 1):
        bar.update(n)
        console.print(bar)
        console.file.write("\r")
        time.sleep(0.03)
    console.show_cursor(True)
    console.print()

    console.print("[bold red]Prompts[/bold red] and [bold red]user input[/bold red] work too")
    answer = Prompt.ask("What is your name?", default="John Doe")
    console.print(f"Hello {answer}!")

==> terminhtml-0.9.0-py3-none-any.whl: terminhtml/demo_output.py <==
# Adapted from rich.__main__.py
import colorsys

from rich.color import Color
from rich.console import ConsoleOptions, Console, RenderResult
from rich.live import Live
from rich.measure import Measurement
from rich.progress_bar import ProgressBar
from rich.prompt import Prompt
from rich.segment import Segment
from rich.spinner import Spinner
from rich.style import Style
from rich.table import Table
from rich.text import Text


class ColorBox:
    def __rich_console__(
        self, console: Console, options: ConsoleOptions
    ) -> RenderResult:
        for y in range(0, 2):
            for x in range(options.max_width):
                h = x / options.max_width
                l = 0.1 + ((y / 5) * 0.7)
                r1, g1, b1 = colorsys.hls_to_rgb(h, l, 1.0)
                r2, g2, b2 = colorsys.hls_to_rgb(h, l + 0.7 / 10, 1.0)
                bgcolor = Color.from_rgb(r1 * 255, g1 * 255, b1 * 255)
                color = Color.from_rgb(r2 * 255, g2 * 255, b2 * 255)
                yield Segment("▄", Style(color=color, bgcolor=bgcolor))
            yield Segment.line()

    def __rich_measure__(
        self, console: "Console", options: ConsoleOptions
    ) -> Measurement:
        return Measurement(1, options.max_width)


def make_test_card() -> Table:
    """Get a renderable that demonstrates a number of features."""
    table = Table.grid(padding=1, pad_edge=True)
    table.title = (
        "Terminal recording into HTML/CSS with full color and animation support"
    )
    table.add_column("Feature", no_wrap=True, justify="center", style="bold red")
    table.add_column("Demonstration")

    color_table = Table(
        box=None,
        expand=False,
        show_header=False,
        show_edge=False,
        pad_edge=False,
    )
    color_table.add_row(
        ("✓ [bold green]4-bit color[/]\n" "✓ [bold blue]8-bit color[/]\n"),
        ColorBox(),
    )

    table.add_row("Colors", color_table)

    table.add_row(
        "Styles",
        "Most ansi styles: [bold]bold[/], [italic]italic[/italic], [underline]underline[/], [strike]strikethrough[/], [reverse]reverse[/].",
    )

    return table


if __name__ == "__main__":  # pragma: no cover
    console = Console()
    test_card = make_test_card()
    console.print(test_card)

    console.print(
        "[bold red]Progress bars[/bold red] and [bold red]spinners[/bold red] work too"
    )

    bar = ProgressBar(width=50, total=100)

    import time

    console.show_cursor(False)
    for n in range(0, 101, 1):
        bar.update(n)
        console.print(bar)
        console.file.write("\r")
        time.sleep(0.02)
    console.show_cursor(True)
    console.print()

    spinner = Spinner("dots", text=Text("Loading...", style="green"))

    with Live(spinner) as live:
        time.sleep(2)

    console.print(
        "\n[bold red]Prompts[/bold red] and passing custom [bold red]user input[/bold red] work too"
    )
    answer = Prompt.ask("What is your name?", default="John Doe")
    console.print(f"Hello {answer}!")
